# Gears

Gears is a lightweight framework for writing control flow with LLMs. It allows you to build complex chains of actions and conditions, and execute them in a single call. You have full control over the prompts; you just provide the text and control flow and Gears will handle the rest.

TODO:

- [ ] Write docs
